@@ -75,12 +75,12 @@ ovn_opts = [
                       'connection transaction')),
     cfg.IntOpt('ovsdb_probe_interval',
                min=0,
-               default=0,
+               default=60000,
                help=_('The probe interval in for the OVSDB session in '
                       'milliseconds. If this is zero, it disables the '
                       'connection keepalive feature. If non-zero the value '
-                      'will be forced to at least 1000 milliseconds. Probing '
-                      'is disabled by default.')),
+                      'will be forced to at least 1000 milliseconds. Defaults '
+                      'to 60 seconds.')),
     cfg.StrOpt('neutron_sync_mode',
                default='log',
                choices=('off', 'log', 'repair'),
@@ -146,7 +146,14 @@ ovn_opts = [
                help=_("The log level used for OVSDB")),
     cfg.BoolOpt('ovn_metadata_enabled',
                 default=False,
-                help=_('Whether to use metadata service.'))
+                help=_('Whether to use metadata service.')),
+    cfg.ListOpt('dns_servers',
+                default=[],
+                help=_("Comma-separated list of the DNS servers which will be "
+                       "used as forwarders if a subnet's dns_nameservers "
+                       "field is empty. If both subnet's dns_nameservers and "
+                       "this option is empty, then the DNS resolvers on the "
+                       "host running the neutron server will be used.")),
 ]
 
 cfg.CONF.register_opts(ovn_opts, group='ovn')
@@ -230,6 +237,10 @@ def is_ovn_metadata_enabled():
     return cfg.CONF.ovn.ovn_metadata_enabled
 
 
+def get_dns_servers():
+    return cfg.CONF.ovn.dns_servers
+
+
 def setup_logging():
     """Sets up the logging options for a log with supplied name."""
     product_name = "networking-ovn"
