@@ -86,9 +86,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         LOG.debug("Starting OVN-Northbound DB sync process")
 
         ctx = context.get_admin_context()
-
         self.sync_address_sets(ctx)
-        self.sync_port_groups(ctx)
         self.sync_networks_ports_and_dhcp_opts(ctx)
         self.sync_port_dns_records(ctx)
         self.sync_acls(ctx)
@@ -167,74 +165,6 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
     def get_address_sets(self):
         return self.ovn_api.get_address_sets()
 
-    def sync_port_groups(self, ctx):
-        """Sync Port Groups between neutron and NB.
-
-        @param ctx: neutron_lib.context
-        @type  ctx: object of type neutron_lib.context.Context
-        """
-        if not self.ovn_api.is_port_groups_supported():
-            return
-
-        neutron_sgs = {}
-        neutron_pgs = set()
-        with ctx.session.begin(subtransactions=True):
-            for sg in self.core_plugin.get_security_groups(ctx):
-                pg_name = utils.ovn_port_group_name(sg['id'])
-                neutron_pgs.add(pg_name)
-                neutron_sgs[pg_name] = sg['id']
-            neutron_pgs.add(const.OVN_DROP_PORT_GROUP_NAME)
-
-        ovn_pgs = set()
-        port_groups = self.ovn_api.db_list_rows('Port_Group').execute() or []
-        for pg in port_groups:
-            ovn_pgs.add(pg.name)
-
-        add_pgs = neutron_pgs.difference(ovn_pgs)
-        remove_pgs = ovn_pgs.difference(neutron_pgs)
-
-        LOG.debug('Port Groups added %d, removed %d',
-                  len(add_pgs), len(remove_pgs))
-
-        if self.mode == SYNC_MODE_REPAIR:
-            LOG.debug('Port-Group-SYNC: transaction started @ %s',
-                      str(datetime.now()))
-            if add_pgs:
-                db_ports = self.core_plugin.get_ports(ctx)
-                ovn_ports = set(p.name for p in
-                                self.ovn_api.lsp_list().execute())
-            with self.ovn_api.transaction(check_error=True) as txn:
-                pg = const.OVN_DROP_PORT_GROUP_NAME
-                # Process default drop port group first
-                if pg in add_pgs:
-                    txn.add(self.ovn_api.pg_add(name=pg, acls=[]))
-                    add_pgs.remove(pg)
-                    # Add ports to the drop port group. Only add those that
-                    # already exists in OVN. The rest will be added during the
-                    # ports sync operation later.
-                    for n_port in db_ports:
-                        if ((n_port['security_groups'] or
-                                n_port['port_security_enabled']) and
-                                n_port['id'] in ovn_ports):
-                            txn.add(self.ovn_api.pg_add_ports(
-                                pg, n_port['id']))
-
-                for pg in add_pgs:
-                    # If it's a security group PG, add the ext id
-                    ext_ids = {const.OVN_SG_EXT_ID_KEY: neutron_sgs[pg]}
-                    txn.add(self.ovn_api.pg_add(name=pg, acls=[],
-                                                external_ids=ext_ids))
-                    # Add the ports belonging to the SG to this port group
-                    for n_port in db_ports:
-                        if (neutron_sgs[pg] in n_port['security_groups'] and
-                                n_port['id'] in ovn_ports):
-                            txn.add(self.ovn_api.pg_add_ports(
-                                pg, n_port['id']))
-                for pg in remove_pgs:
-                    txn.add(self.ovn_api.pg_del(pg))
-            LOG.debug('Port-Group-SYNC: transaction finished @ %s',
-                      str(datetime.now()))
-
     def sync_address_sets(self, ctx):
         """Sync Address Sets between neutron and NB.
 
@@ -244,39 +174,32 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         """
         LOG.debug('Address-Set-SYNC: started @ %s' % str(datetime.now()))
 
-        sgnames_to_add = sgnames_to_delete = []
-        sgs_to_update = {}
+        neutron_sgs = {}
+        with ctx.session.begin(subtransactions=True):
+            db_sgs = self.core_plugin.get_security_groups(ctx)
+            db_ports = self.core_plugin.get_ports(ctx)
+
+        for sg in db_sgs:
+            for ip_version in ['ip4', 'ip6']:
+                name = utils.ovn_addrset_name(sg['id'], ip_version)
+                neutron_sgs[name] = {
+                    'name': name, 'addresses': [],
+                    'external_ids': {const.OVN_SG_EXT_ID_KEY: sg['id']}}
+
+        for port in db_ports:
+            sg_ids = utils.get_lsp_security_groups(port)
+            if port.get('fixed_ips') and sg_ids:
+                addresses = acl_utils.acl_port_ips(port)
+                for sg_id in sg_ids:
+                    for ip_version in addresses:
+                        name = utils.ovn_addrset_name(sg_id, ip_version)
+                        neutron_sgs[name]['addresses'].extend(
+                            addresses[ip_version])
+
         nb_sgs = self.get_address_sets()
 
-        if self.ovn_api.is_port_groups_supported():
-            # If Port Groups are supported, we just need to delete all Address
-            # Sets from NB database.
-            sgnames_to_delete = nb_sgs.keys()
-        else:
-            neutron_sgs = {}
-            with ctx.session.begin(subtransactions=True):
-                db_sgs = self.core_plugin.get_security_groups(ctx)
-                db_ports = self.core_plugin.get_ports(ctx)
-
-            for sg in db_sgs:
-                for ip_version in ['ip4', 'ip6']:
-                    name = utils.ovn_addrset_name(sg['id'], ip_version)
-                    neutron_sgs[name] = {
-                        'name': name, 'addresses': [],
-                        'external_ids': {const.OVN_SG_EXT_ID_KEY: sg['id']}}
-
-            for port in db_ports:
-                sg_ids = utils.get_lsp_security_groups(port)
-                if port.get('fixed_ips') and sg_ids:
-                    addresses = acl_utils.acl_port_ips(port)
-                    for sg_id in sg_ids:
-                        for ip_version in addresses:
-                            name = utils.ovn_addrset_name(sg_id, ip_version)
-                            neutron_sgs[name]['addresses'].extend(
-                                addresses[ip_version])
-
-            sgnames_to_add, sgnames_to_delete, sgs_to_update =\
-                self.compute_address_set_difference(neutron_sgs, nb_sgs)
+        sgnames_to_add, sgnames_to_delete, sgs_to_update =\
+            self.compute_address_set_difference(neutron_sgs, nb_sgs)
 
         LOG.debug('Address_Sets added %d, removed %d, updated %d',
                   len(sgnames_to_add), len(sgnames_to_delete),
@@ -296,85 +219,8 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             LOG.debug('Address-Set-SYNC: transaction finished @ %s' %
                       str(datetime.now()))
 
-    def _get_acls_from_port_groups(self):
-        ovn_acls = []
-        port_groups = self.ovn_api.db_list_rows('Port_Group').execute()
-        for pg in port_groups:
-            acls = getattr(pg, 'acls', [])
-            for acl in acls:
-                acl_string = {}
-                acl_string['port_group'] = pg.name
-                for acl_key in getattr(acl, "_data", {}):
-                    acl_string[acl_key] = getattr(acl, acl_key)
-                acl_string.pop('meter')
-                acl_string.pop('external_ids')
-                ovn_acls.append(acl_string)
-        return ovn_acls
-
-    def _sync_acls_port_groups(self, ctx):
-        # If Port Groups are supported, the ACLs in the system will equal
-        # the number of SG rules plus the default drop rules as OVN would
-        # allow all traffic by default if those are not added.
-        neutron_acls = []
-        for sgr in self.core_plugin.get_security_group_rules(ctx):
-            pg_name = utils.ovn_port_group_name(sgr['security_group_id'])
-            neutron_acls.append(acl_utils._add_sg_rule_acl_for_port_group(
-                pg_name, sgr, self.ovn_api))
-        neutron_acls += acl_utils.add_acls_for_drop_port_group(
-            const.OVN_DROP_PORT_GROUP_NAME)
-
-        ovn_acls = self._get_acls_from_port_groups()
-
-        # We need to remove also all the ACLs applied to Logical Switches
-        def get_num_acls(ovn_acls):
-            return len([item for sublist in ovn_acls for item in sublist[1]])
-
-        ovn_acls_from_ls = [(row.name, row.acls) for row in (
-            self.ovn_api._tables['Logical_Switch'].rows.values())]
-        num_acls_to_remove_from_ls = get_num_acls(ovn_acls_from_ls)
-
-        # Remove the common ones
-        for na in list(neutron_acls):
-            for ovn_a in ovn_acls:
-                if all(item in na.items() for item in ovn_a.items()):
-                    neutron_acls.remove(na)
-                    ovn_acls.remove(ovn_a)
-                    break
-
-        num_acls_to_add = len(neutron_acls)
-        num_acls_to_remove = len(ovn_acls) + num_acls_to_remove_from_ls
-        if 0 != num_acls_to_add or 0 != num_acls_to_remove:
-            LOG.warning('ACLs-to-be-added %(add)d '
-                        'ACLs-to-be-removed %(remove)d',
-                        {'add': num_acls_to_add,
-                         'remove': num_acls_to_remove})
-
-        if self.mode == SYNC_MODE_REPAIR:
-            with self.ovn_api.transaction(check_error=True) as txn:
-                for acla in neutron_acls:
-                    LOG.warning('ACL found in Neutron but not in '
-                                'OVN DB for port group %s', acla['port_group'])
-                    txn.add(self.ovn_api.pg_acl_add(**acla))
-
-            with self.ovn_api.transaction(check_error=True) as txn:
-                for aclr in ovn_acls:
-                    LOG.warning('ACLs found in OVN DB but not in '
-                                'Neutron for port group %s',
-                                aclr['port_group'])
-                    txn.add(self.ovn_api.pg_acl_del(aclr['port_group'],
-                                                    aclr['direction'],
-                                                    aclr['priority'],
-                                                    aclr['match']))
-                for aclr in ovn_acls_from_ls:
-                    # Remove all the ACLs from any Logical Switch if they have
-                    # any. Elements are (lswitch_name, list_of_acls).
-                    if len(aclr[1]) > 0:
-                        LOG.warning('Removing ACLs from OVN from Logical '
-                                    'Switch %s', aclr[0])
-                        txn.add(self.ovn_api.acl_del(aclr[0]))
-
-    def _sync_acls(self, ctx):
-        """Sync ACLs between neutron and NB when not using Port Groups.
+    def sync_acls(self, ctx):
+        """Sync ACLs between neutron and NB.
 
         @param ctx: neutron_lib.context
         @type  ctx: object of type neutron_lib.context.Context
@@ -386,6 +232,9 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
         @var   subnet_cache: cache for subnets
         @return: Nothing
         """
+        LOG.debug('ACL-SYNC: started @ %s' %
+                  str(datetime.now()))
+
         db_ports = {}
         for port in self.core_plugin.get_ports(ctx):
             db_ports[port['id']] = port
@@ -441,21 +290,6 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                         is_add_acl=False
                     ))
 
-    def sync_acls(self, ctx):
-        """Sync ACLs between neutron and NB.
-
-        @param ctx: neutron_lib.context
-        @type  ctx: object of type neutron_lib.context.Context
-        @return: Nothing
-        """
-        LOG.debug('ACL-SYNC: started @ %s' %
-                  str(datetime.now()))
-
-        if self.ovn_api.is_port_groups_supported():
-            self._sync_acls_port_groups(ctx)
-        else:
-            self._sync_acls(ctx)
-
         LOG.debug('ACL-SYNC: finished @ %s' %
                   str(datetime.now()))
 
@@ -515,26 +349,20 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
             db_extends[router['id']]['fips'] = []
             if not router.get(l3.EXTERNAL_GW_INFO):
                 continue
-            gateways = self._ovn_client._get_gw_info(ctx, router)
-            for gw_info in gateways:
-                prefix = (constants.IPv4_ANY if
-                          gw_info.ip_version == constants.IP_VERSION_4 else
-                          constants.IPv6_ANY)
-                if gw_info.gateway_ip:
-                    db_extends[router['id']]['routes'].append(
-                        {'destination': prefix,
-                         'nexthop': gw_info.gateway_ip})
-                if gw_info.ip_version == constants.IP_VERSION_6:
-                    continue
-                if gw_info.router_ip and utils.is_snat_enabled(router):
-                    networks = (
-                        self._ovn_client._get_v4_network_of_all_router_ports(
-                            ctx, router['id']))
-                    for network in networks:
-                        db_extends[router['id']]['snats'].append({
-                            'logical_ip': network,
-                            'external_ip': gw_info.router_ip,
-                            'type': 'snat'})
+            gw_info = self._ovn_client._get_gw_info(ctx, router)
+            if gw_info.gateway_ip:
+                db_extends[router['id']]['routes'].append(
+                    {'destination': '0.0.0.0/0',
+                     'nexthop': gw_info.gateway_ip})
+            if gw_info.router_ip and utils.is_snat_enabled(router):
+                networks = (
+                    self._ovn_client._get_v4_network_of_all_router_ports(
+                        ctx, router['id']))
+                for network in networks:
+                    db_extends[router['id']]['snats'].append({
+                        'logical_ip': network,
+                        'external_ip': gw_info.router_ip,
+                        'type': 'snat'})
 
         fips = self.l3_plugin.get_floatingips(
             ctx, {'router_id': list(db_routers.keys())})
@@ -641,7 +469,7 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                 try:
                     LOG.warning("Creating the router port %s in OVN NB DB",
                                 rrport['id'])
-                    self._ovn_client._create_lrouter_port(
+                    self._ovn_client.create_router_port(
                         rrport['device_id'], rrport)
                 except RuntimeError:
                     LOG.warning("Create router port in OVN "
@@ -1108,83 +936,6 @@ class OvnNbSynchronizer(OvnDbSynchronizer):
                 txn.add(self.ovn_api.dns_set_records(ls_dns_record.uuid,
                                                      **dns_records))
 
-    def _delete_address_sets(self, ctx):
-        with self.ovn_api.transaction(check_error=True) as txn:
-            for sg in self.core_plugin.get_security_groups(ctx):
-                for ip_version in ['ip4', 'ip6']:
-                    txn.add(self.ovn_api.delete_address_set(
-                        utils.ovn_addrset_name(sg['id'], ip_version)))
-
-    def _delete_acls_from_lswitches(self, ctx):
-        with self.ovn_api.transaction(check_error=True) as txn:
-            for net in self.core_plugin.get_networks(ctx):
-                # Calling acl_del from ovsdbapp with no ACL will delete
-                # all the ACLs belonging to that Logical Switch.
-                txn.add(self.ovn_api.acl_del(utils.ovn_name(net['id'])))
-
-    def _create_default_drop_port_group(self, db_ports):
-        with self.ovn_api.transaction(check_error=True) as txn:
-            pg_name = const.OVN_DROP_PORT_GROUP_NAME
-            if not self.ovn_api.get_port_group(pg_name):
-                # If drop Port Group doesn't exist yet, create it.
-                txn.add(self.ovn_api.pg_add(pg_name, acls=[]))
-                # Add ACLs to this Port Group so that all traffic is dropped.
-                acls = acl_utils.add_acls_for_drop_port_group(pg_name)
-                for acl in acls:
-                    txn.add(self.ovn_api.pg_acl_add(**acl))
-            ports_ids = [port['id'] for port in db_ports]
-            # Add the ports to the default Port Group
-            txn.add(self.ovn_api.pg_add_ports(pg_name, ports_ids))
-
-    def _create_sg_port_groups_and_acls(self, ctx, db_ports):
-        # Create a Port Group per Neutron Security Group
-        with self.ovn_api.transaction(check_error=True) as txn:
-            for sg in self.core_plugin.get_security_groups(ctx):
-                pg_name = utils.ovn_port_group_name(sg['id'])
-                if self.ovn_api.get_port_group(pg_name):
-                    continue
-                ext_ids = {const.OVN_SG_EXT_ID_KEY: sg['id']}
-                txn.add(self.ovn_api.pg_add(
-                    name=pg_name, acls=[], external_ids=ext_ids))
-                acl_utils.add_acls_for_sg_port_group(self.ovn_api, sg, txn)
-            for port in db_ports:
-                for sg in port['security_groups']:
-                    txn.add(self.ovn_api.pg_add_ports(
-                        utils.ovn_port_group_name(sg), port['id']))
-
-    def migrate_to_port_groups(self, ctx):
-        # This routine is responsible for migrating the current Security
-        # Groups and SG Rules to the new Port Groups implementation.
-        # 1. Create the default drop Port Group and add all ports with port
-        #    security enabled to it.
-        # 2. Create a Port Group for every existing Neutron Security Group and
-        #    add all its Security Group Rules as ACLs to that Port Group.
-        # 3. Delete all existing Address Sets in NorthBound database which
-        #    correspond to a Neutron Security Group.
-        # 4. Delete all the ACLs in every Logical Switch (Neutron network).
-
-        # If Port Groups are not supported or we've already migrated, return
-        if (not self.ovn_api.is_port_groups_supported() or
-                not self.ovn_api.get_address_sets()):
-            return
-
-        LOG.debug('Port Groups Migration task started')
-
-        # Ignore the floating ip ports with device_owner set to
-        # constants.DEVICE_OWNER_FLOATINGIP
-        db_ports = [port for port in
-                    self.core_plugin.get_ports(ctx) if not
-                    utils.is_lsp_ignored(port) and not
-                    utils.is_lsp_trusted(port) and
-                    utils.is_port_security_enabled(port)]
-
-        self._create_default_drop_port_group(db_ports)
-        self._create_sg_port_groups_and_acls(ctx, db_ports)
-        self._delete_address_sets(ctx)
-        self._delete_acls_from_lswitches(ctx)
-
-        LOG.debug('Port Groups Migration task finished')
-
 
 class OvnSbSynchronizer(OvnDbSynchronizer):
     """Synchronizer class for SB."""
