@@ -12,8 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-
 from neutron.services.segments import db as segments_db
 from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.extensions import test_extraroute
@@ -63,8 +61,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
         self.create_address_sets = []
         self.delete_address_sets = []
         self.update_address_sets = []
-        self.create_port_groups = []
-        self.delete_port_groups = []
         self.expected_dhcp_options_rows = []
         self.reset_lport_dhcpv4_options = []
         self.reset_lport_dhcpv6_options = []
@@ -351,12 +347,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                                                      'end': '100.0.0.253'}],
                                   enable_dhcp=False)
         e1_s1 = self.deserialize(self.fmt, res)
-        res = self._create_subnet(self.fmt, e1['network']['id'],
-                                  '2001:db8::/64',
-                                  gateway_ip='fd05:59e4:ef16::1',
-                                  ip_version=constants.IP_VERSION_6,
-                                  enable_dhcp=False)
-        e1_s2 = self.deserialize(self.fmt, res)
 
         self.create_lswitches.append('neutron-' + uuidutils.generate_uuid())
         self.create_lswitch_ports.append(('neutron-' +
@@ -380,9 +370,7 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                     'network_id': e1['network']['id'],
                     'external_fixed_ips': [
                         {'ip_address': '100.0.0.2',
-                         'subnet_id': e1_s1['subnet']['id']},
-                        {'ip_address': '2001:db8::23a',
-                         'subnet_id': e1_s2['subnet']['id']}]}}})
+                         'subnet_id': e1_s1['subnet']['id']}]}}})
         self.l3_plugin.add_router_interface(
             self.context, r1['id'], {'subnet_id': n1_s1['subnet']['id']})
         r1_p2 = self.l3_plugin.add_router_interface(
@@ -577,10 +565,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
         self.update_address_sets.append((address_set_name, 'ip4',
                                          address_adds, address_dels))
 
-        self.create_port_groups.extend([{'name': 'pg1', 'acls': []},
-                                        {'name': 'pg2', 'acls': []}])
-        self.delete_port_groups.append(
-            utils.ovn_port_group_name(n1_prtr['port']['security_groups'][0]))
         # Create a network and subnet with orphaned OVN resources.
         n3 = self._make_network(self.fmt, 'n3', True)
         res = self._create_subnet(self.fmt, n3['network']['id'],
@@ -761,12 +745,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                 txn.add(self.nb_api.update_address_set(ovn_name,
                                                        ip_adds, ip_dels, True))
 
-            if self.nb_api.is_port_groups_supported():
-                for pg in self.create_port_groups:
-                    txn.add(self.nb_api.pg_add(**pg))
-                for pg in self.delete_port_groups:
-                    txn.add(self.nb_api.pg_del(pg))
-
             for lport_name in self.reset_lport_dhcpv4_options:
                 txn.add(self.nb_api.set_lswitch_port(lport_name, True,
                                                      dhcpv4_options=[]))
@@ -991,20 +969,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                 AssertionError, self.assertItemsEqual, db_port_ids,
                 monitor_lport_ids_dhcpv4_enabled)
 
-    @staticmethod
-    def _build_acl_for_pgs(priority, direction, log, name, action,
-                           severity, match, port_group, **kwargs):
-        return {
-            'priority': priority,
-            'direction': direction,
-            'log': log,
-            'name': name,
-            'action': action,
-            'severity': severity,
-            'match': match,
-            'external_ids': kwargs,
-            }
-
     def _validate_dhcp_opts(self, should_match=True):
         observed_plugin_dhcp_options_rows = []
         _plugin_nb_ovn = self.mech_driver._nb_ovn
@@ -1049,66 +1013,42 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                 self.expected_dhcp_options_rows,
                 observed_monitor_dhcp_options_rows)
 
-    def _build_acl_to_compare(self, acl, extra_fields=None):
+    def _build_acl_to_compare(self, acl):
         acl_to_compare = {}
         for acl_key in getattr(acl, "_data", {}):
             try:
                 acl_to_compare[acl_key] = getattr(acl, acl_key)
             except AttributeError:
                 pass
-        return acl_utils.filter_acl_dict(acl_to_compare, extra_fields)
+        return acl_utils.filter_acl_dict(acl_to_compare)
 
     def _validate_acls(self, should_match=True):
         # Get the neutron DB ACLs.
         db_acls = []
         sg_cache = {}
         subnet_cache = {}
-
-        _plugin_nb_ovn = self.mech_driver._nb_ovn
-        if not _plugin_nb_ovn.is_port_groups_supported():
-            for db_port in self._list('ports')['ports']:
-                acls = acl_utils.add_acls(self.plugin,
-                                          context.get_admin_context(),
-                                          db_port,
-                                          sg_cache,
-                                          subnet_cache,
-                                          self.mech_driver._nb_ovn)
-                for acl in acls:
-                    db_acls.append(acl_utils.filter_acl_dict(acl))
-        else:
-            # ACLs due to SGs and default drop port group
-            for sg in self._list('security-groups')['security_groups']:
-                for sgr in sg['security_group_rules']:
-                    acl = acl_utils._add_sg_rule_acl_for_port_group(
-                        utils.ovn_port_group_name(sg['id']), sgr,
-                        self.mech_driver._nb_ovn)
-                    db_acls.append(TestOvnNbSync._build_acl_for_pgs(**acl))
-
-            for acl in acl_utils.add_acls_for_drop_port_group(
-                    ovn_const.OVN_DROP_PORT_GROUP_NAME):
-                db_acls.append(TestOvnNbSync._build_acl_for_pgs(**acl))
+        for db_port in self._list('ports')['ports']:
+            acls = acl_utils.add_acls(self.plugin,
+                                      context.get_admin_context(),
+                                      db_port,
+                                      sg_cache,
+                                      subnet_cache,
+                                      self.mech_driver._nb_ovn)
+            for acl in acls:
+                db_acls.append(acl_utils.filter_acl_dict(acl))
 
         # Get the list of ACLs stored in the OVN plugin IDL.
+        _plugin_nb_ovn = self.mech_driver._nb_ovn
         plugin_acls = []
         for row in _plugin_nb_ovn._tables['Logical_Switch'].rows.values():
             for acl in getattr(row, 'acls', []):
                 plugin_acls.append(self._build_acl_to_compare(acl))
-        if self.nb_api.is_port_groups_supported():
-            for row in _plugin_nb_ovn._tables['Port_Group'].rows.values():
-                for acl in getattr(row, 'acls', []):
-                    plugin_acls.append(
-                        self._build_acl_to_compare(
-                            acl, extra_fields=['external_ids']))
 
         # Get the list of ACLs stored in the OVN monitor IDL.
         monitor_acls = []
         for row in self.nb_api.tables['Logical_Switch'].rows.values():
             for acl in getattr(row, 'acls', []):
                 monitor_acls.append(self._build_acl_to_compare(acl))
-        if _plugin_nb_ovn.is_port_groups_supported():
-            for row in self.nb_api.tables['Port_Group'].rows.values():
-                for acl in getattr(row, 'acls', []):
-                    monitor_acls.append(self._build_acl_to_compare(acl))
 
         if should_match:
             self.assertItemsEqual(db_acls, plugin_acls)
@@ -1133,22 +1073,19 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                                           for db_route in db_router['routes']]
             db_nats[db_router['id']] = []
             if db_router.get(l3.EXTERNAL_GW_INFO):
-                gateways = self.l3_plugin._ovn_client._get_gw_info(
+                gw_info = self.l3_plugin._ovn_client._get_gw_info(
                     self.context, db_router)
-                for gw_info in gateways:
-                    # Add gateway default route and snats
-                    if gw_info.gateway_ip:
-                        db_routes[db_router['id']].append(gw_info.ip_prefix +
-                                                          gw_info.gateway_ip)
-                    if (gw_info.ip_version == constants.IP_VERSION_4 and
-                            gw_info.router_ip and
-                            utils.is_snat_enabled(db_router)):
-                        networks = self.l3_plugin._ovn_client.\
-                            _get_v4_network_of_all_router_ports(
-                                self.context, db_router['id'])
-                        db_nats[db_router['id']].extend(
-                            [gw_info.router_ip + network + 'snat'
-                             for network in networks])
+                # Add gateway default route and snats
+                if gw_info.gateway_ip:
+                    db_routes[db_router['id']].append('0.0.0.0/0' +
+                                                      gw_info.gateway_ip)
+                if gw_info.router_ip and utils.is_snat_enabled(db_router):
+                    networks = self.l3_plugin._ovn_client.\
+                        _get_v4_network_of_all_router_ports(self.context,
+                                                            db_router['id'])
+                    db_nats[db_router['id']].extend(
+                        [gw_info.router_ip + network + 'snat'
+                         for network in networks])
         fips = self._list('floatingips')
         fip_macs = {}
         if ovn_config.is_ovn_distributed_floating_ip():
@@ -1161,6 +1098,7 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                 mac_address = ''
                 fip_port = ''
                 if fip['id'] in fip_macs:
+                    mac_address = fip_macs[fip['id']]
                     fip_port = fip['port_id']
                 db_nats[fip['router_id']].append(
                     fip['floating_ip_address'] + fip['fixed_ip_address'] +
@@ -1331,34 +1269,27 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
                     monitor_nats)
 
     def _validate_address_sets(self, should_match=True):
+        db_ports = self._list('ports')['ports']
+        sgs = self._list('security-groups')['security_groups']
+        db_sgs = {}
+        for sg in sgs:
+            for ip_version in ['ip4', 'ip6']:
+                name = utils.ovn_addrset_name(sg['id'], ip_version)
+                db_sgs[name] = []
+
+        for port in db_ports:
+            sg_ids = utils.get_lsp_security_groups(port)
+            addresses = acl_utils.acl_port_ips(port)
+            for sg_id in sg_ids:
+                for ip_version in addresses:
+                    name = utils.ovn_addrset_name(sg_id, ip_version)
+                    db_sgs[name].extend(addresses[ip_version])
+
         _plugin_nb_ovn = self.mech_driver._nb_ovn
-        if _plugin_nb_ovn.is_port_groups_supported():
-            # If Port Groups are supported, no Address Sets are expected.
-            # This validation is still useful as we expect existing ones to
-            # be deleted after the sync.
-            db_sgs = []
-        else:
-            db_ports = self._list('ports')['ports']
-            sgs = self._list('security-groups')['security_groups']
-            db_sgs = {}
-            for sg in sgs:
-                for ip_version in ['ip4', 'ip6']:
-                    name = utils.ovn_addrset_name(sg['id'], ip_version)
-                    db_sgs[name] = []
-
-            for port in db_ports:
-                sg_ids = utils.get_lsp_security_groups(port)
-                addresses = acl_utils.acl_port_ips(port)
-                for sg_id in sg_ids:
-                    for ip_version in addresses:
-                        name = utils.ovn_addrset_name(sg_id, ip_version)
-                        db_sgs[name].extend(addresses[ip_version])
-
         nb_address_sets = _plugin_nb_ovn.get_address_sets()
         nb_sgs = {}
         for nb_sgid, nb_values in nb_address_sets.items():
             nb_sgs[nb_sgid] = nb_values['addresses']
-
         mn_sgs = {}
         for row in self.nb_api.tables['Address_Set'].rows.values():
             mn_sgs[getattr(row, 'name')] = getattr(row, 'addresses')
@@ -1366,41 +1297,11 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
         if should_match:
             self.assertItemsEqual(nb_sgs, db_sgs)
             self.assertItemsEqual(mn_sgs, db_sgs)
-        else:
-            # This condition is to cover the case when we use Port Groups
-            # and we completely deleted the NB DB. At this point, the expected
-            # number of Address Sets is 0 and the observed number in NB is
-            # also 0 so we can't have the asserts below as both will be empty.
-            if _plugin_nb_ovn.is_port_groups_supported() and nb_sgs:
-                self.assertRaises(AssertionError, self.assertItemsEqual,
-                                  nb_sgs, db_sgs)
-                self.assertRaises(AssertionError, self.assertItemsEqual,
-                                  mn_sgs, db_sgs)
-
-    def _validate_port_groups(self, should_match=True):
-        _plugin_nb_ovn = self.mech_driver._nb_ovn
-        if not _plugin_nb_ovn.is_port_groups_supported():
-            return
-
-        db_pgs = []
-        for sg in self._list('security-groups')['security_groups']:
-            db_pgs.append(utils.ovn_port_group_name(sg['id']))
-        db_pgs.append(ovn_const.OVN_DROP_PORT_GROUP_NAME)
-
-        nb_pgs = _plugin_nb_ovn.get_port_groups()
-
-        mn_pgs = []
-        for row in self.nb_api.tables['Port_Group'].rows.values():
-            mn_pgs.append(getattr(row, 'name', ''))
-
-        if should_match:
-            self.assertItemsEqual(nb_pgs, db_pgs)
-            self.assertItemsEqual(mn_pgs, db_pgs)
         else:
             self.assertRaises(AssertionError, self.assertItemsEqual,
-                              nb_pgs, db_pgs)
+                              nb_sgs, db_sgs)
             self.assertRaises(AssertionError, self.assertItemsEqual,
-                              mn_pgs, db_pgs)
+                              mn_sgs, db_sgs)
 
     def _delete_metadata_ports(self):
         """Delete some metadata ports.
@@ -1454,7 +1355,6 @@ class TestOvnNbSync(base.TestOVNFunctionalBase):
         self._validate_acls(should_match=should_match)
         self._validate_routers_and_router_ports(should_match=should_match)
         self._validate_address_sets(should_match=should_match)
-        self._validate_port_groups(should_match=should_match)
         self._validate_dns_records(should_match=should_match)
 
     def _sync_resources(self, mode):
@@ -1613,9 +1513,3 @@ class TestOvnNbSyncOverSsl(TestOvnNbSync):
 class TestOvnSbSyncOverSsl(TestOvnSbSync):
     def get_ovsdb_server_protocol(self):
         return 'ssl'
-
-
-@mock.patch('networking_ovn.ovsdb.impl_idl_ovn.OvsdbNbOvnIdl.'
-            'is_port_groups_supported', lambda *args: False)
-class TestOvnNbSyncNoPgs(TestOvnNbSync):
-    pass
